@@ -295,6 +295,7 @@ static void test_begindrag(void)
     drag = ImageList_GetDragImage(NULL, NULL);
     ok(ret && drag, "ImageList drag was created\n");
     ImageList_EndDrag();
+    ImageList_Destroy(himl);
 }
 
 static void test_hotspot(void)
@@ -1253,7 +1254,7 @@ static void test_imagelist_storage(void)
 
 static void test_shell_imagelist(void)
 {
-    BOOL (WINAPI *pSHGetImageList)(INT, REFIID, void**);
+    HRESULT (WINAPI *pSHGetImageList)(INT, REFIID, void**);
     IImageList *iml = NULL;
     HMODULE hShell32;
     HRESULT hr;
@@ -1273,8 +1274,7 @@ static void test_shell_imagelist(void)
     }
 
     /* Get system image list */
-    hr = (pSHGetImageList)(SHIL_SYSSMALL, &IID_IImageList, (void**)&iml);
-
+    hr = pSHGetImageList(SHIL_SYSSMALL, &IID_IImageList, (void**)&iml);
     ok(SUCCEEDED(hr), "SHGetImageList failed, hr=%x\n", hr);
 
     if (hr != S_OK) {
