@@ -399,7 +399,7 @@ HRESULT freetype_get_glyph_outline(IDWriteFontFace2 *fontface, FLOAT emSize, UIN
 
     EnterCriticalSection(&freetype_cs);
     if (pFTC_Manager_LookupSize(cache_manager, &scaler, &size) == 0) {
-         if (pFT_Load_Glyph(size->face, index, FT_LOAD_DEFAULT) == 0) {
+         if (pFT_Load_Glyph(size->face, index, FT_LOAD_NO_BITMAP) == 0) {
              FT_Outline *outline = &size->face->glyph->outline;
              short count;
              FT_Matrix m;
@@ -641,7 +641,7 @@ INT freetype_get_charmap_index(IDWriteFontFace2 *fontface, BOOL *is_symbol)
             if (os2->version == 0)
                 *is_symbol = pFT_Get_First_Char(face, &dummy) >= 0x100;
             else
-                *is_symbol = os2->ulCodePageRange1 & FS_SYMBOL;
+                *is_symbol = !!(os2->ulCodePageRange1 & FS_SYMBOL);
         }
 
         for (i = 0; i < face->num_charmaps; i++)
