@@ -22,7 +22,6 @@
 
 #define COBJMACROS
 #define NONAMELESSUNION
-#define NONAMELESSSTRUCT
 
 #include "winerror.h"
 #include "windef.h"
@@ -687,9 +686,9 @@ static LRESULT on_nm_click(NSTC2Impl *This, NMHDR *nmhdr)
     psi = shellitem_from_treeitem(This, tvhit.hItem);
     hr = events_OnItemClick(This, psi, tvhit.flags, NSTCECT_LBUTTON);
 
-    /* The expando should not be expanded unless
+    /* The label should not be expanded unless
      * double-clicked. */
-    if(tvhit.flags == TVHT_ONITEMBUTTON)
+    if(tvhit.flags == TVHT_ONITEMLABEL)
         return TRUE;
 
     if(SUCCEEDED(hr))
@@ -819,7 +818,7 @@ static HRESULT WINAPI NSTC2_fnQueryInterface(INameSpaceTreeControl2* iface,
        IsEqualIID(riid, &IID_INameSpaceTreeControl) ||
        IsEqualIID(riid, &IID_IUnknown))
     {
-        *ppvObject = This;
+        *ppvObject = &This->INameSpaceTreeControl2_iface;
     }
     else if(IsEqualIID(riid, &IID_IOleWindow))
     {
