@@ -1206,39 +1206,6 @@ static HRESULT WINAPI DocHostContainer_SetStatusText(DocHost* This, LPCWSTR text
 
 static void WINAPI DocHostContainer_SetURL(DocHost* This, LPCWSTR url)
 {
-
-}
-
-static HRESULT DocHostContainer_exec(DocHost *doc_host, const GUID *cmd_group, DWORD cmdid, DWORD execopt, VARIANT *in,
-        VARIANT *out)
-{
-    WebBrowser *This = impl_from_DocHost(doc_host);
-    IOleCommandTarget *cmdtrg = NULL;
-    HRESULT hres;
-
-    if(This->client) {
-        hres = IOleClientSite_QueryInterface(This->client, &IID_IOleCommandTarget, (void**)&cmdtrg);
-        if(FAILED(hres))
-            cmdtrg = NULL;
-    }
-
-    if(!cmdtrg && This->container) {
-        hres = IOleContainer_QueryInterface(This->container, &IID_IOleCommandTarget, (void**)&cmdtrg);
-        if(FAILED(hres))
-            cmdtrg = NULL;
-    }
-
-    if(!cmdtrg)
-        return E_NOTIMPL;
-
-    hres = IOleCommandTarget_Exec(cmdtrg, cmd_group, cmdid, execopt, in, out);
-    IOleCommandTarget_Release(cmdtrg);
-    if(SUCCEEDED(hres))
-        TRACE("Exec returned %08x %s\n", hres, debugstr_variant(out));
-    else
-        FIXME("Exec failed\n");
-
-    return hres;
 }
 
 static const IDocHostContainerVtbl DocHostContainerVtbl = {
@@ -1246,8 +1213,7 @@ static const IDocHostContainerVtbl DocHostContainerVtbl = {
     WebBrowser_release,
     DocHostContainer_GetDocObjRect,
     DocHostContainer_SetStatusText,
-    DocHostContainer_SetURL,
-    DocHostContainer_exec
+    DocHostContainer_SetURL
 };
 
 static HRESULT create_webbrowser(int version, IUnknown *outer, REFIID riid, void **ppv)
