@@ -661,6 +661,21 @@ int CDECL MSVCRT__snscanf_s_l(char *input, MSVCRT_size_t length,
     return res;
 }
 
+
+/*********************************************************************
+ *		__stdio_common_vsscanf (MSVCRT.@)
+ */
+int CDECL MSVCRT__stdio_common_vsscanf(unsigned __int64 options,
+                                       const char *input, MSVCRT_size_t length,
+                                       const char *format,
+                                       MSVCRT__locale_t locale,
+                                       __ms_va_list valist)
+{
+    if (options != 2)
+        FIXME("options %s not handled\n", wine_dbgstr_longlong(options));
+    return MSVCRT_vsnscanf_l(input, length, format, locale, valist);
+}
+
 /*********************************************************************
  *		_snwscanf (MSVCRT.@)
  */
