@@ -1584,3 +1584,14 @@ BOOL WINAPI RtlSetCurrentTransaction(HANDLE new_transaction)
     FIXME("(%p) :stub\n", new_transaction);
     return FALSE;
 }
+
+/**********************************************************************
+ *           RtlGetCurrentProcessorNumberEx [NTDLL.@]
+ */
+void WINAPI RtlGetCurrentProcessorNumberEx(PROCESSOR_NUMBER *processor)
+{
+    FIXME("(%p) :semi-stub\n", processor);
+    processor->Group = 0;
+    processor->Number = NtGetCurrentProcessorNumber();
+    processor->Reserved = 0;
+}
