@@ -1933,7 +1933,6 @@ static void test_default_handler(void)
     fmtetc.lindex = -1;
     fmtetc.tymed = TYMED_ENHMF;
     hr = IDataObject_QueryGetData(pDataObject, &fmtetc);
-    todo_wine
     ok(hr == OLE_E_NOTRUNNING, "IDataObject_QueryGetData should have returned OLE_E_NOTRUNNING instead of 0x%08x\n", hr);
 
     fmtetc.cfFormat = CF_TEXT;
@@ -1942,7 +1941,6 @@ static void test_default_handler(void)
     fmtetc.lindex = -1;
     fmtetc.tymed = TYMED_NULL;
     hr = IDataObject_QueryGetData(pDataObject, &fmtetc);
-    todo_wine
     ok(hr == OLE_E_NOTRUNNING, "IDataObject_QueryGetData should have returned OLE_E_NOTRUNNING instead of 0x%08x\n", hr);
 
     hr = IOleObject_QueryInterface(pObject, &IID_IRunnableObject, (void **)&pRunnableObject);
@@ -2104,7 +2102,7 @@ static ULONG WINAPI OleRun_Release(IRunnableObject *iface)
 
 static HRESULT WINAPI OleRun_GetRunningClass(IRunnableObject *iface, CLSID *clsid)
 {
-    ok(0, "unxpected\n");
+    ok(0, "unexpected\n");
     return E_NOTIMPL;
 }
 
@@ -2116,20 +2114,20 @@ static HRESULT WINAPI OleRun_Run(IRunnableObject *iface, LPBINDCTX ctx)
 
 static BOOL WINAPI OleRun_IsRunning(IRunnableObject *iface)
 {
-    ok(0, "unxpected\n");
+    ok(0, "unexpected\n");
     return FALSE;
 }
 
 static HRESULT WINAPI OleRun_LockRunning(IRunnableObject *iface, BOOL lock,
     BOOL last_unlock_closes)
 {
-    ok(0, "unxpected\n");
+    ok(0, "unexpected\n");
     return E_NOTIMPL;
 }
 
 static HRESULT WINAPI OleRun_SetContainedObject(IRunnableObject *iface, BOOL contained)
 {
-    ok(0, "unxpected\n");
+    ok(0, "unexpected\n");
     return E_NOTIMPL;
 }
 
