@@ -25,6 +25,7 @@
 #include "xaudio2.h"
 #include "xaudio2fx.h"
 #include "xapo.h"
+#include "xapofx.h"
 #include "mmsystem.h"
 
 static BOOL xaudio27;
@@ -174,6 +175,7 @@ static void test_simple_streaming(IXAudio2 *xa)
     XAUDIO2_VOICE_STATE state;
     XAUDIO2_EFFECT_DESCRIPTOR effect;
     XAUDIO2_EFFECT_CHAIN chain;
+    DWORD chmask;
 
     memset(&ecb_state, 0, sizeof(ecb_state));
     memset(&src1_state, 0, sizeof(src1_state));
@@ -196,6 +198,12 @@ static void test_simple_streaming(IXAudio2 *xa)
         hr = IXAudio2_CreateMasteringVoice(xa, &master, 2, 44100, 0, NULL, NULL, AudioCategory_GameEffects);
     ok(hr == S_OK, "CreateMasteringVoice failed: %08x\n", hr);
 
+    if(!xaudio27){
+        chmask = 0xdeadbeef;
+        IXAudio2MasteringVoice_GetChannelMask(master, &chmask);
+        ok(chmask == (SPEAKER_FRONT_LEFT | SPEAKER_FRONT_RIGHT), "Got unexpected channel mask: 0x%x\n", chmask);
+    }
+
     /* create first source voice */
     fmt.wFormatTag = WAVE_FORMAT_IEEE_FLOAT;
     fmt.nChannels = 2;
@@ -239,12 +247,26 @@ static void test_simple_streaming(IXAudio2 *xa)
 
     /* hook up volume meter */
     if(xaudio27){
+        IXAPO *xapo;
+
         hr = CoCreateInstance(&CLSID_AudioVolumeMeter, NULL,
                 CLSCTX_INPROC_SERVER, &IID_IUnknown, (void**)&vumeter);
         ok(hr == S_OK, "CoCreateInstance(AudioVolumeMeter) failed: %08x\n", hr);
+
+        hr = IUnknown_QueryInterface(vumeter, &IID_IXAPO27, (void**)&xapo);
+        ok(hr == S_OK, "Couldn't get IXAPO27 interface: %08x\n", hr);
+        if(SUCCEEDED(hr))
+            IXAPO_Release(xapo);
     }else{
+        IXAPO *xapo;
+
         hr = pCreateAudioVolumeMeter(&vumeter);
         ok(hr == S_OK, "CreateAudioVolumeMeter failed: %08x\n", hr);
+
+        hr = IUnknown_QueryInterface(vumeter, &IID_IXAPO, (void**)&xapo);
+        ok(hr == S_OK, "Couldn't get IXAPO interface: %08x\n", hr);
+        if(SUCCEEDED(hr))
+            IXAPO_Release(xapo);
     }
 
     effect.InitialState = TRUE;
@@ -771,6 +793,233 @@ static UINT32 test_DeviceDetails(IXAudio27 *xa)
     return count;
 }
 
+static void test_xapo_creation_legacy(const char *module, unsigned int version)
+{
+    HANDLE xapofxdll;
+    HRESULT hr;
+    IUnknown *fx_unk;
+    unsigned int i;
+
+    HRESULT (CDECL *pCreateFX)(REFCLSID,IUnknown**) = NULL;
+
+    /* CLSIDs are the same across all versions */
+    static struct {
+        const GUID *clsid;
+        BOOL todo;
+    } const_clsids[] = {
+        { &CLSID_FXEQ27, FALSE },
+        { &CLSID_FXMasteringLimiter27, TRUE },
+        { &CLSID_FXReverb27, FALSE },
+        { &CLSID_FXEcho27, TRUE},
+        /* older versions of xapofx actually have support for new clsids */
+        { &CLSID_FXEQ, FALSE },
+        { &CLSID_FXMasteringLimiter, TRUE },
+        { &CLSID_FXReverb, FALSE },
+        { &CLSID_FXEcho, TRUE}
+    };
+
+    /* different CLSID for each version */
+    static const GUID *avm_clsids[] = {
+        &CLSID_AudioVolumeMeter20,
+        &CLSID_AudioVolumeMeter21,
+        &CLSID_AudioVolumeMeter22,
+        &CLSID_AudioVolumeMeter23,
+        &CLSID_AudioVolumeMeter24,
+        &CLSID_AudioVolumeMeter25,
+        &CLSID_AudioVolumeMeter26,
+        &CLSID_AudioVolumeMeter
+    };
+
+    static const GUID *ar_clsids[] = {
+        &CLSID_AudioReverb20,
+        &CLSID_AudioReverb21,
+        &CLSID_AudioReverb22,
+        &CLSID_AudioReverb23,
+        &CLSID_AudioReverb24,
+        &CLSID_AudioReverb25,
+        &CLSID_AudioReverb26,
+        &CLSID_AudioReverb
+    };
+
+    xapofxdll = LoadLibraryA(module);
+    if(xapofxdll){
+        pCreateFX = (void*)GetProcAddress(xapofxdll, "CreateFX");
+        ok(pCreateFX != NULL, "%s did not have CreateFX?\n", module);
+        if(!pCreateFX){
+            FreeLibrary(xapofxdll);
+            return;
+        }
+    }else{
+        win_skip("Couldn't load %s\n", module);
+        return;
+    }
+
+    if(pCreateFX){
+        for(i = 0; i < sizeof(const_clsids) / sizeof(*const_clsids); ++i){
+            hr = pCreateFX(const_clsids[i].clsid, &fx_unk);
+            if(const_clsids[i].todo)
+                todo_wine ok(hr == S_OK, "%s: CreateFX(%s) failed: %08x\n", module, wine_dbgstr_guid(const_clsids[i].clsid), hr);
+            else
+                ok(hr == S_OK, "%s: CreateFX(%s) failed: %08x\n", module, wine_dbgstr_guid(const_clsids[i].clsid), hr);
+            if(SUCCEEDED(hr)){
+                IXAPO *xapo;
+                hr = IUnknown_QueryInterface(fx_unk, &IID_IXAPO27, (void**)&xapo);
+                ok(hr == S_OK, "Couldn't get IXAPO27 interface: %08x\n", hr);
+                if(SUCCEEDED(hr))
+                    IXAPO_Release(xapo);
+                IUnknown_Release(fx_unk);
+            }
+
+            hr = CoCreateInstance(const_clsids[i].clsid, NULL, CLSCTX_INPROC_SERVER,
+                    &IID_IUnknown, (void**)&fx_unk);
+            ok(hr == REGDB_E_CLASSNOTREG, "CoCreateInstance should have failed: %08x\n", hr);
+            if(SUCCEEDED(hr))
+                IUnknown_Release(fx_unk);
+        }
+
+        hr = pCreateFX(avm_clsids[version - 20], &fx_unk);
+        ok(hr == S_OK, "%s: CreateFX(%s) failed: %08x\n", module, wine_dbgstr_guid(avm_clsids[version - 20]), hr);
+        if(SUCCEEDED(hr)){
+            IXAPO *xapo;
+            hr = IUnknown_QueryInterface(fx_unk, &IID_IXAPO27, (void**)&xapo);
+            ok(hr == S_OK, "Couldn't get IXAPO27 interface: %08x\n", hr);
+            if(SUCCEEDED(hr))
+                IXAPO_Release(xapo);
+            IUnknown_Release(fx_unk);
+        }
+
+        hr = pCreateFX(ar_clsids[version - 20], &fx_unk);
+        ok(hr == S_OK, "%s: CreateFX(%s) failed: %08x\n", module, wine_dbgstr_guid(ar_clsids[version - 20]), hr);
+        if(SUCCEEDED(hr)){
+            IXAPO *xapo;
+            hr = IUnknown_QueryInterface(fx_unk, &IID_IXAPO27, (void**)&xapo);
+            ok(hr == S_OK, "Couldn't get IXAPO27 interface: %08x\n", hr);
+            if(SUCCEEDED(hr))
+                IXAPO_Release(xapo);
+            IUnknown_Release(fx_unk);
+        }
+    }
+
+    FreeLibrary(xapofxdll);
+}
+
+static void test_xapo_creation_modern(const char *module)
+{
+    HANDLE xaudio2dll;
+    HRESULT hr;
+    IUnknown *fx_unk;
+    unsigned int i;
+
+    HRESULT (CDECL *pCreateFX)(REFCLSID,IUnknown**,void*,UINT32) = NULL;
+    HRESULT (WINAPI *pCAVM)(IUnknown**) = NULL;
+    HRESULT (WINAPI *pCAR)(IUnknown**) = NULL;
+
+    /* CLSIDs are the same across all versions */
+    static struct {
+        const GUID *clsid;
+        BOOL todo;
+    } const_clsids[] = {
+        { &CLSID_FXEQ27, FALSE },
+        { &CLSID_FXMasteringLimiter27, TRUE },
+        { &CLSID_FXReverb27, FALSE },
+        { &CLSID_FXEcho27, TRUE},
+        { &CLSID_FXEQ, FALSE },
+        { &CLSID_FXMasteringLimiter, TRUE },
+        { &CLSID_FXReverb, FALSE },
+        { &CLSID_FXEcho, TRUE}
+    };
+
+    xaudio2dll = LoadLibraryA(module);
+    if(xaudio2dll){
+        pCreateFX = (void*)GetProcAddress(xaudio2dll, "CreateFX");
+        ok(pCreateFX != NULL, "%s did not have CreateFX?\n", module);
+        if(!pCreateFX){
+            FreeLibrary(xaudio2dll);
+            return;
+        }
+    }else{
+        win_skip("Couldn't load %s\n", module);
+        return;
+    }
+
+    if(pCreateFX){
+        for(i = 0; i < sizeof(const_clsids) / sizeof(*const_clsids); ++i){
+            hr = pCreateFX(const_clsids[i].clsid, &fx_unk, NULL, 0);
+            if(const_clsids[i].todo)
+                todo_wine ok(hr == S_OK, "%s: CreateFX(%s) failed: %08x\n", module, wine_dbgstr_guid(const_clsids[i].clsid), hr);
+            else
+                ok(hr == S_OK, "%s: CreateFX(%s) failed: %08x\n", module, wine_dbgstr_guid(const_clsids[i].clsid), hr);
+            if(SUCCEEDED(hr)){
+                IXAPO *xapo;
+                hr = IUnknown_QueryInterface(fx_unk, &IID_IXAPO, (void**)&xapo);
+                ok(hr == S_OK, "Couldn't get IXAPO interface: %08x\n", hr);
+                if(SUCCEEDED(hr))
+                    IXAPO_Release(xapo);
+                IUnknown_Release(fx_unk);
+            }
+
+            hr = CoCreateInstance(const_clsids[i].clsid, NULL, CLSCTX_INPROC_SERVER,
+                    &IID_IUnknown, (void**)&fx_unk);
+            ok(hr == REGDB_E_CLASSNOTREG, "CoCreateInstance should have failed: %08x\n", hr);
+            if(SUCCEEDED(hr))
+                IUnknown_Release(fx_unk);
+        }
+
+        /* test legacy CLSID */
+        hr = pCreateFX(&CLSID_AudioVolumeMeter, &fx_unk, NULL, 0);
+        ok(hr == S_OK, "%s: CreateFX(CLSID_AudioVolumeMeter) failed: %08x\n", module, hr);
+        if(SUCCEEDED(hr)){
+            IXAPO *xapo;
+            hr = IUnknown_QueryInterface(fx_unk, &IID_IXAPO, (void**)&xapo);
+            ok(hr == S_OK, "Couldn't get IXAPO interface: %08x\n", hr);
+            if(SUCCEEDED(hr))
+                IXAPO_Release(xapo);
+            IUnknown_Release(fx_unk);
+        }
+    }
+
+    pCAVM = (void*)GetProcAddress(xaudio2dll, "CreateAudioVolumeMeter");
+    ok(pCAVM != NULL, "%s did not have CreateAudioVolumeMeter?\n", module);
+
+    hr = pCAVM(&fx_unk);
+    ok(hr == S_OK, "CreateAudioVolumeMeter failed: %08x\n", hr);
+    if(SUCCEEDED(hr)){
+        IXAPO *xapo;
+        hr = IUnknown_QueryInterface(fx_unk, &IID_IXAPO, (void**)&xapo);
+        ok(hr == S_OK, "Couldn't get IXAPO interface: %08x\n", hr);
+        if(SUCCEEDED(hr))
+            IXAPO_Release(xapo);
+        IUnknown_Release(fx_unk);
+    }
+
+    pCAR = (void*)GetProcAddress(xaudio2dll, "CreateAudioReverb");
+    ok(pCAR != NULL, "%s did not have CreateAudioReverb?\n", module);
+
+    hr = pCAR(&fx_unk);
+    ok(hr == S_OK, "CreateAudioReverb failed: %08x\n", hr);
+    if(SUCCEEDED(hr)){
+        IXAPO *xapo;
+        hr = IUnknown_QueryInterface(fx_unk, &IID_IXAPO, (void**)&xapo);
+        ok(hr == S_OK, "Couldn't get IXAPO interface: %08x\n", hr);
+        if(SUCCEEDED(hr))
+            IXAPO_Release(xapo);
+        IUnknown_Release(fx_unk);
+    }
+
+    FreeLibrary(xaudio2dll);
+}
+
+static void test_xapo_creation(void)
+{
+    test_xapo_creation_legacy("xapofx1_1.dll", 22);
+    test_xapo_creation_legacy("xapofx1_2.dll", 23);
+    test_xapo_creation_legacy("xapofx1_3.dll", 24);
+    test_xapo_creation_legacy("xapofx1_3.dll", 25);
+    test_xapo_creation_legacy("xapofx1_4.dll", 26);
+    test_xapo_creation_legacy("xapofx1_5.dll", 27);
+    test_xapo_creation_modern("xaudio2_8.dll");
+}
+
 static UINT32 check_has_devices(IXAudio2 *xa)
 {
     HRESULT hr;
@@ -801,6 +1050,8 @@ START_TEST(xaudio2)
         pCreateAudioVolumeMeter = (void*)GetProcAddress(xa28dll, "CreateAudioVolumeMeter");
     }
 
+    test_xapo_creation();
+
     /* XAudio 2.7 (Jun 2010 DirectX) */
     hr = CoCreateInstance(&CLSID_XAudio2, NULL, CLSCTX_INPROC_SERVER,
             &IID_IXAudio27, (void**)&xa27);
