@@ -48,6 +48,8 @@ typedef struct _BCRYPT_ALGORITHM_IDENTIFIER
 } BCRYPT_ALGORITHM_IDENTIFIER;
 
 typedef PVOID BCRYPT_ALG_HANDLE;
+typedef PVOID BCRYPT_HANDLE;
+typedef PVOID BCRYPT_HASH_HANDLE;
 
 #define BCRYPT_RNG_USE_ENTROPY_IN_BUFFER 0x00000001
 #define BCRYPT_USE_SYSTEM_PREFERRED_RNG  0x00000002
